@@ -2,11 +2,12 @@ package Plack::Middleware::IIS6ScriptNameFix;
 
 use strict;
 use parent 'Plack::Middleware';
+use Plack::Util::Accessor qw(force);
 
 sub call {
     my($self, $env) = @_;
 
-    if ($env->{SERVER_SOFTWARE} && $env->{SERVER_SOFTWARE} =~ /IIS\/[6-9]\.[0-9]/) {
+    if ($self->force || ($env->{SERVER_SOFTWARE} && $env->{SERVER_SOFTWARE} =~ /IIS\/[6-9]\.[0-9]/)) {
         my @script_name = split(m!/!, $env->{PATH_INFO});
         my @path_translated = split(m!/|\\\\?!, $env->{PATH_TRANSLATED});
         my @path_info;
@@ -50,6 +51,23 @@ Plack::Middleware::IIS6ScriptNameFix - fixes wrong SCRIPT_NAME and PATH_INFO tha
 
 This middleware fixes wrong C<SCRIPT_NAME> and C<PATH_INFO> set by IIS6.
 
+=head1 OPTIONS
+
+=over 4
+
+=item force
+
+By default, this middleware checks if C<SERVER_SOFTWARE> PSGI environment
+matches what Microsoft IIS server 6-9 would set for FastCGI. By setting C<force>
+to true (1), this middleware always applies the fix, regardless of the
+C<SERVER_SOFTWARE> string.
+
+Use this option if the environment is broken similar to IIS, or if the IIS is
+updated and the regular expression in this module doesn't match any more
+e.g. you're running IIS 10.
+
+=back
+
 =head1 AUTHORS
 
 Florian Ragwitz
